@@ -47,7 +47,7 @@ using namespace KontactInterface;
   @internal
 */
 //@cond PRIVATE
-class Plugin::Private
+class Q_DECL_HIDDEN Plugin::Private
 {
 public:
 
@@ -169,11 +169,6 @@ KParts::ReadOnlyPart *Plugin::part()
     return d->part;
 }
 
-QString Plugin::tipFile() const
-{
-    return QString();
-}
-
 QString Plugin::registerClient()
 {
     if (d->serviceName.isEmpty()) {
@@ -287,7 +282,7 @@ void Plugin::Private::removeInvisibleToolbarActions(Plugin *plugin)
                 QDomElement nextActionElem = actionElem.nextSiblingElement();
                 if (QString::compare(actionElem.tagName(), QLatin1String("Action"), Qt::CaseInsensitive) == 0) {
                     //qCDebug(KONTACTINTERFACE_LOG) << "Looking at action" << actionElem.attribute("name");
-                    if (hideActions.contains(actionElem.attribute(QLatin1String("name")))) {
+                    if (hideActions.contains(actionElem.attribute(QStringLiteral("name")))) {
                         //qCDebug(KONTACTINTERFACE_LOG) << "REMOVING";
                         containerElem.removeChild(actionElem);
                     }
